@@ -32,8 +32,11 @@ before 'setup' => sub {
     );
   }
   
-  my $DiffObj = $self->_migrate_and_diff_deployed;
+  my ($DiffObj,$schemsum) = $self->_migrate_and_diff_deployed;
   
+  my $fn = (reverse split(/\//,$db_path))[0];
+  warn '  ** ' . __PACKAGE__ . " - loaded $fn [$schemsum]\n";
+
   my $diff = $DiffObj
     ->filter_out('*:relationships')
     ->filter_out('*:constraints')
@@ -80,7 +83,7 @@ sub _migrate_and_diff_deployed {
 
   $self->_migrate_for_schemsum($schemsum) 
     ? $self->_migrate_and_diff_deployed($seen)
-    : $DiffObj
+    : ($DiffObj,$schemsum)
 }
 
 # Dynamic, signature-based migrations
@@ -121,6 +124,7 @@ sub _migrate_for_schemsum {
   }
 }
 
+
 # This is the migration from the last dev state before public 1.000 release... was
 # never seen in the wild (this entry made for test/dev as we never expect to see it)
 sub _run_migrate_schemsum_7ef8b36d22d6c7d {
@@ -197,7 +201,7 @@ FROM [temp_user]
   return 1
 }
 
-
+# This is the first public migration, adds categories
 sub _run_migrate_schemsum_8955354febf5675 {
   my $self = shift;
   
@@ -230,6 +234,90 @@ q~CREATE TABLE [post_category] (
 }
 
 
+# This is the second public migration from the schema as of v1.0101 release... 
+sub _run_migrate_schemsum_6c99c16bdcb0fab {
+  my $self = shift;
+  
+  my @statements = (
+    'PRAGMA foreign_keys=off',
+    'BEGIN TRANSACTION',
+    
+q~CREATE TABLE [section] (
+  [id] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+  [name] varchar(64) NOT NULL,
+  [description] varchar(1024) DEFAULT NULL,
+  [parent_id] INTEGER DEFAULT NULL,
+  
+  FOREIGN KEY ([parent_id]) REFERENCES [section] ([id]) ON DELETE CASCADE ON UPDATE CASCADE
+)~,
+'CREATE UNIQUE INDEX [unique_subsection] ON [section] ([parent_id],[name])',
+
+    'ALTER TABLE [post] RENAME TO [temp_post]',q~
+CREATE TABLE [post] (
+  [id] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+  [name] varchar(255) UNIQUE NOT NULL,
+  [title] varchar(255) DEFAULT NULL,
+  [image] varchar(255) DEFAULT NULL,
+  [ts] datetime NOT NULL,
+  [create_ts] datetime NOT NULL,
+  [update_ts] datetime NOT NULL,
+  [author_id] INTEGER NOT NULL,
+  [creator_id] INTEGER NOT NULL,
+  [updater_id] INTEGER NOT NULL,
+  [section_id] INTEGER DEFAULT NULL,
+  [published] BOOLEAN NOT NULL DEFAULT 0,
+  [publish_ts] datetime DEFAULT NULL,
+  [size] INTEGER DEFAULT NULL,
+  [tag_names] text default NULL,
+  [custom_summary] text default NULL,
+  [summary] text default NULL,
+  [body] text default '',
+  
+  FOREIGN KEY ([author_id])  REFERENCES [user]    ([id]) ON DELETE RESTRICT    ON UPDATE CASCADE,
+  FOREIGN KEY ([creator_id]) REFERENCES [user]    ([id]) ON DELETE RESTRICT    ON UPDATE CASCADE,
+  FOREIGN KEY ([updater_id]) REFERENCES [user]    ([id]) ON DELETE RESTRICT    ON UPDATE CASCADE,
+  FOREIGN KEY ([section_id]) REFERENCES [section] ([id]) ON DELETE SET DEFAULT ON UPDATE CASCADE
+)~, q~
+INSERT INTO [post] SELECT
+  [id],[name],[title],[image],[ts],[create_ts],[update_ts],[author_id],[creator_id],
+  [updater_id],null,[published],[publish_ts],[size],[tag_names],[custom_summary],[summary],[body]
+FROM [temp_post]
+~,
+ 'DROP TABLE [temp_post]',
+ 
+q~CREATE TABLE [trk_section_posts] (
+  [id]            INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+  [section_id]    INTEGER NOT NULL,
+  [post_id]       INTEGER NOT NULL,
+  [depth]         INTEGER NOT NULL,
+  
+  FOREIGN KEY ([section_id]) REFERENCES [section] ([id]) ON DELETE CASCADE ON UPDATE CASCADE,
+  FOREIGN KEY ([post_id])    REFERENCES [post] ([id])    ON DELETE CASCADE ON UPDATE CASCADE
+)~,
+
+q~CREATE TABLE [trk_section_sections] (
+  [id]            INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+  [section_id]    INTEGER NOT NULL,
+  [subsection_id] INTEGER NOT NULL,
+  [depth]         INTEGER NOT NULL,
+  
+  FOREIGN KEY ([section_id])    REFERENCES [section] ([id]) ON DELETE CASCADE ON UPDATE CASCADE,
+  FOREIGN KEY ([subsection_id]) REFERENCES [section] ([id]) ON DELETE CASCADE ON UPDATE CASCADE
+)~, 
+ 
+ 'COMMIT',
+ 'PRAGMA foreign_keys=on',
+  );
+  
+  my $db = $self->_one_off_connect;
+  
+  $db->storage->dbh->do($_) for (@statements);
+ 
+  return 1
+}
+
+
+
 ## This is the migration from the first public release of the schema (v1.0000)
 #sub _run_migrate_schemsum_8955354febf5675 {
 #  my $self = shift;
@@ -571,8 +659,30 @@ __PACKAGE__->config(
           },
           categories => {
             header => 'Categories',
-            width  => 180
-          }
+            width  => 180,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          section_id => {
+            header => 'section_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          section => {
+            header => 'Section',
+            width  => 150,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          trk_section_posts => {
+            header => 'trk_section_posts',
+            #width => 100,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
         },
       },
       PostTag => {
@@ -580,7 +690,7 @@ __PACKAGE__->config(
         title          => 'Post-Tag Link',
         title_multi    => 'Post-Tag Links',
         iconCls        => 'icon-node',
-        multiIconCls   => 'icon-nodes',
+        multiIconCls   => 'icon-logic-and-blue',
         columns        => {
           id => {
             allow_add => 0,
@@ -868,24 +978,24 @@ __PACKAGE__->config(
         display_column => 'name',
         title          => 'Category',
         title_multi    => 'Categories',
-        iconCls        => 'ra-icon-pg',
-        multiIconCls   => 'ra-icon-pg-multi',
+        iconCls        => 'icon-image',
+        multiIconCls   => 'icon-images',
         columns        => {
           name => {
             header => 'name',
-            width => 140,
+            width  => 140,
             #renderer => 'RA.ux.App.someJsFunc',
             #profiles => [],
           },
           description => {
             header => 'description',
-            width => 280,
+            width  => 280,
             #renderer => 'RA.ux.App.someJsFunc',
             #profiles => [],
           },
           post_categories => {
             header => 'post_categories',
-            width => 190,
+            width  => 190,
             #sortable => 1,
             #renderer => 'RA.ux.App.someJsFunc',
             #profiles => [],
@@ -897,12 +1007,12 @@ __PACKAGE__->config(
         title          => 'Post-Category Link',
         title_multi    => 'Post-Category Links',
         iconCls        => 'icon-node',
-        multiIconCls   => 'icon-nodes',
+        multiIconCls   => 'icon-logic-and',
         columns        => {
           id => {
             allow_add => 0,
             header    => 'id',
-            width => 45,
+            width     => 45,
             #renderer => 'RA.ux.App.someJsFunc',
             #profiles => [],
           },
@@ -910,7 +1020,7 @@ __PACKAGE__->config(
             header => 'post_id',
             #width => 100,
             #renderer => 'RA.ux.App.someJsFunc',
-            profiles => [ 'hidden' ],
+            profiles => ['hidden'],
           },
           category_name => {
             header => 'category_name',
@@ -926,6 +1036,173 @@ __PACKAGE__->config(
           },
         },
       },
+      Section => {
+        display_column => 'name',
+        title          => 'Section',
+        title_multi    => 'Sections',
+        iconCls        => 'icon-element',
+        multiIconCls   => 'icon-chart-organisation',
+        columns        => {
+          id => {
+            allow_add => 0,
+            header    => 'id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          parent_id => {
+            header => 'parent_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          name => {
+            header => 'name',
+            width  => 150,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          description => {
+            header => 'description',
+            width  => 280,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          parent => {
+            header => 'parent',
+            width  => 160,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          posts => {
+            header => 'posts',
+            width  => 140,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          sections => {
+            header => 'sections',
+            width  => 140,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          trk_section_posts => {
+            header => 'trk_section_posts',
+            #width => 100,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          trk_section_sections_sections => {
+            header => 'trk_section_sections_sections',
+            #width => 100,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          trk_section_sections_subsections => {
+            header => 'trk_section_sections_subsections',
+            #width => 100,
+            #sortable => 1,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+        },
+      },
+      TrkSectionPost => {
+        display_column => 'id',
+        title          => 'Track Section-Post',
+        title_multi    => 'Track Section-Posts',
+        iconCls        => 'icon-table-relationship',
+        multiIconCls   => 'icon-table-relationship',
+        columns        => {
+          id => {
+            allow_add => 0,
+            header    => 'id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          section_id => {
+            header => 'section_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          post_id => {
+            header => 'post_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          depth => {
+            header => 'depth',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          post => {
+            header => 'post',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          section => {
+            header => 'section',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+        },
+      },
+      TrkSectionSection => {
+        display_column => 'id',
+        title          => 'Track Section-Section',
+        title_multi    => 'Track Section-Sections',
+        iconCls        => 'icon-table-relationship',
+        multiIconCls   => 'icon-table-relationship',
+        columns        => {
+          id => {
+            allow_add => 0,
+            header    => 'id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          section_id => {
+            header => 'section_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          subsection_id => {
+            header => 'subsection_id',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            profiles => ['hidden'],
+          },
+          depth => {
+            header => 'depth',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          section => {
+            header => 'section',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+          subsection => {
+            header => 'subsection',
+            #width => 100,
+            #renderer => 'RA.ux.App.someJsFunc',
+            #profiles => [],
+          },
+        },
+      },
     }
   },
 
